pub struct u8x2(/* private fields */);Expand description
Two u8 values packed as a u16.
Compared to using [u8; 2], this forces the data to have an alignment of 2,
and also keeps volatile reads and writes as a single access (when possible).
Implementations